@@ -1,7 +1,6 @@
-from mail import MultipartMail
-from templates import BasicMailTemplate
-from templates import CheetahMailTemplate
-from utils import safe_unicode
+from iw.email.mail import MultipartMail
+from iw.email.templates import BasicMailTemplate
+from iw.email.templates import CheetahMailTemplate
 
 def CheetahMail(path, format='rst',
                 mfrom=None, mto=None, subject='', **options):
